/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.14.0
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt5.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtWebKitWidgets.h"

#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 29 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"

#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobject.sip"
#include <qobject.h>
#line 33 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 61 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebframe.sip"
#include <qwebframe.h>
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebsecurityorigin.sip"
#include <qwebsecurityorigin.h>
#line 39 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 27 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstring.sip"
#include <qstring.h>
#line 42 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 36 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qrect.sip"
#include <qrect.h>
#line 48 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 378 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 53 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qsize.sip"
#include <qsize.h>
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpoint.sip"
#include <qpoint.h>
#line 59 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebhistory.sip"
#include <qwebhistory.h>
#line 62 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qmenu.sip"
#include <qmenu.h>
#line 65 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 109 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qurl.sip"
#include <qurl.h>
#line 68 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtNetwork/qnetworkrequest.sip"
#include <qnetworkrequest.h>
#line 71 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtNetwork/qnetworkreply.sip"
#include <qnetworkreply.h>
#line 74 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 211 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 79 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 218 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 84 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 482 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qevent.sip"
#include <qevent.h>
#line 87 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtGui/qpalette.sip"
#include <qpalette.h>
#line 90 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKitWidgets/qwebpage.sip"
#include <qwebpage.h>
#line 93 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qvariant.sip"
#include <qvariant.h>
#line 96 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 99 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 102 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qaction.sip"
#include <qaction.h>
#line 105 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebpluginfactory.sip"
#include <qwebpluginfactory.h>
#line 108 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtNetwork/qnetworkaccessmanager.sip"
#include <qnetworkaccessmanager.h>
#line 111 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 56 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qundostack.sip"
#include <qundostack.h>
#line 114 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 28 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWidgets/qwidget.sip"
#include <qwidget.h>
#line 117 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebsettings.sip"
#include <qwebsettings.h>
#line 120 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 45 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtWebKit/qwebhistory.sip"
#include <qwebhistory.h>
#line 123 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 128 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 131 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 252 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 134 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 240 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 137 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 38 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 140 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 30 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 143 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 146 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qthread.sip"
#include <qthread.h>
#line 149 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 152 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregexp.sip"
#include <qregexp.h>
#line 155 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 158 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"
#line 26 "/build/pyqt5/src/PyQt5-5.15.11/sip/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 161 "/build/pyqt5/src/PyQt5-5.15.11/build/QtWebKitWidgets/sipQtWebKitWidgetsQWebPage.cpp"


class sipQWebPage : public ::QWebPage
{
public:
    sipQWebPage(::QObject*);
    virtual ~sipQWebPage();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool shouldInterruptJavaScript() SIP_OVERRIDE;
    ::QString userAgentForUrl(const ::QUrl&) const SIP_OVERRIDE;
    void javaScriptConsoleMessage(const ::QString&, int, const ::QString&) SIP_OVERRIDE;
    bool javaScriptPrompt(::QWebFrame*, const ::QString&, const ::QString&, ::QString*) SIP_OVERRIDE;
    bool javaScriptConfirm(::QWebFrame*, const ::QString&) SIP_OVERRIDE;
    void javaScriptAlert(::QWebFrame*, const ::QString&) SIP_OVERRIDE;
    ::QString chooseFile(::QWebFrame*, const ::QString&) SIP_OVERRIDE;
    bool acceptNavigationRequest(::QWebFrame*, const ::QNetworkRequest&, ::QWebPage::NavigationType) SIP_OVERRIDE;
    ::QObject* createPlugin(const ::QString&, const ::QUrl&, const ::QStringList&, const ::QStringList&) SIP_OVERRIDE;
    ::QWebPage* createWindow(::QWebPage::WebWindowType) SIP_OVERRIDE;
    bool supportsExtension(::QWebPage::Extension) const SIP_OVERRIDE;
    bool extension(::QWebPage::Extension, const ::QWebPage::ExtensionOption*, ::QWebPage::ExtensionReturn*) SIP_OVERRIDE;
    void triggerAction(::QWebPage::WebAction, bool) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQWebPage(const sipQWebPage &);
    sipQWebPage &operator = (const sipQWebPage &);

    char sipPyMethods[20];
};

sipQWebPage::sipQWebPage(::QObject*a0): ::QWebPage(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQWebPage::~sipQWebPage()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQWebPage::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtWebKitWidgets_qt_metaobject(sipPySelf, sipType_QWebPage);

    return ::QWebPage::metaObject();
}

int sipQWebPage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QWebPage::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtWebKitWidgets_qt_metacall(sipPySelf, sipType_QWebPage, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQWebPage::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtWebKitWidgets_qt_metacast(sipPySelf, sipType_QWebPage, _clname, &sipCpp) ? sipCpp : ::QWebPage::qt_metacast(_clname));
}

bool sipQWebPage::shouldInterruptJavaScript()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_shouldInterruptJavaScript);

    if (!sipMeth)
        return ::QWebPage::shouldInterruptJavaScript();

    extern bool sipVH_QtWebKitWidgets_41(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtWebKitWidgets_41(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QString sipQWebPage::userAgentForUrl(const ::QUrl& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_userAgentForUrl);

    if (!sipMeth)
        return ::QWebPage::userAgentForUrl(a0);

    extern ::QString sipVH_QtWebKitWidgets_70(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QUrl&);

    return sipVH_QtWebKitWidgets_70(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebPage::javaScriptConsoleMessage(const ::QString& a0, int a1, const ::QString& a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_javaScriptConsoleMessage);

    if (!sipMeth)
    {
        ::QWebPage::javaScriptConsoleMessage(a0, a1, a2);
        return;
    }

    extern void sipVH_QtWebKitWidgets_69(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&, int, const ::QString&);

    sipVH_QtWebKitWidgets_69(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

bool sipQWebPage::javaScriptPrompt(::QWebFrame*a0, const ::QString& a1, const ::QString& a2, ::QString*a3)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_javaScriptPrompt);

    if (!sipMeth)
        return ::QWebPage::javaScriptPrompt(a0, a1, a2, a3);

    extern bool sipVH_QtWebKitWidgets_68(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWebFrame*, const ::QString&, const ::QString&, ::QString*);

    return sipVH_QtWebKitWidgets_68(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

bool sipQWebPage::javaScriptConfirm(::QWebFrame*a0, const ::QString& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_javaScriptConfirm);

    if (!sipMeth)
        return ::QWebPage::javaScriptConfirm(a0, a1);

    extern bool sipVH_QtWebKitWidgets_67(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWebFrame*, const ::QString&);

    return sipVH_QtWebKitWidgets_67(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQWebPage::javaScriptAlert(::QWebFrame*a0, const ::QString& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_javaScriptAlert);

    if (!sipMeth)
    {
        ::QWebPage::javaScriptAlert(a0, a1);
        return;
    }

    extern void sipVH_QtWebKitWidgets_66(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWebFrame*, const ::QString&);

    sipVH_QtWebKitWidgets_66(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

::QString sipQWebPage::chooseFile(::QWebFrame*a0, const ::QString& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_chooseFile);

    if (!sipMeth)
        return ::QWebPage::chooseFile(a0, a1);

    extern ::QString sipVH_QtWebKitWidgets_65(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWebFrame*, const ::QString&);

    return sipVH_QtWebKitWidgets_65(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQWebPage::acceptNavigationRequest(::QWebFrame*a0, const ::QNetworkRequest& a1, ::QWebPage::NavigationType a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_acceptNavigationRequest);

    if (!sipMeth)
        return ::QWebPage::acceptNavigationRequest(a0, a1, a2);

    extern bool sipVH_QtWebKitWidgets_64(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWebFrame*, const ::QNetworkRequest&, ::QWebPage::NavigationType);

    return sipVH_QtWebKitWidgets_64(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

::QObject* sipQWebPage::createPlugin(const ::QString& a0, const ::QUrl& a1, const ::QStringList& a2, const ::QStringList& a3)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_createPlugin);

    if (!sipMeth)
        return ::QWebPage::createPlugin(a0, a1, a2, a3);

    extern ::QObject* sipVH_QtWebKitWidgets_63(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QString&, const ::QUrl&, const ::QStringList&, const ::QStringList&);

    return sipVH_QtWebKitWidgets_63(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2, a3);
}

::QWebPage* sipQWebPage::createWindow(::QWebPage::WebWindowType a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_createWindow);

    if (!sipMeth)
        return ::QWebPage::createWindow(a0);

    extern ::QWebPage* sipVH_QtWebKitWidgets_62(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWebPage::WebWindowType);

    return sipVH_QtWebKitWidgets_62(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQWebPage::supportsExtension(::QWebPage::Extension a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[10]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_supportsExtension);

    if (!sipMeth)
        return ::QWebPage::supportsExtension(a0);

    extern bool sipVH_QtWebKitWidgets_61(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWebPage::Extension);

    return sipVH_QtWebKitWidgets_61(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQWebPage::extension(::QWebPage::Extension a0, const ::QWebPage::ExtensionOption*a1, ::QWebPage::ExtensionReturn*a2)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_extension);

    if (!sipMeth)
        return ::QWebPage::extension(a0, a1, a2);

    extern bool sipVH_QtWebKitWidgets_60(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWebPage::Extension, const ::QWebPage::ExtensionOption*, ::QWebPage::ExtensionReturn*);

    return sipVH_QtWebKitWidgets_60(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1, a2);
}

void sipQWebPage::triggerAction(::QWebPage::WebAction a0, bool a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_triggerAction);

    if (!sipMeth)
    {
        ::QWebPage::triggerAction(a0, a1);
        return;
    }

    extern void sipVH_QtWebKitWidgets_59(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWebPage::WebAction, bool);

    sipVH_QtWebKitWidgets_59(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQWebPage::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[13], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QWebPage::event(a0);

    extern bool sipVH_QtWebKitWidgets_9(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtWebKitWidgets_9(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQWebPage::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[14], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QWebPage::eventFilter(a0, a1);

    extern bool sipVH_QtWebKitWidgets_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtWebKitWidgets_18(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQWebPage::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[15], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QWebPage::timerEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtWebKitWidgets_17(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebPage::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[16], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QWebPage::childEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtWebKitWidgets_16(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebPage::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[17], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QWebPage::customEvent(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_0(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtWebKitWidgets_0(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebPage::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[18], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QWebPage::connectNotify(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWebKitWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQWebPage::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[19], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QWebPage::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtWebKitWidgets_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtWebKitWidgets_15(sipGILState, sipImportedVirtErrorHandlers_QtWebKitWidgets_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QWebPage_mainFrame, "mainFrame(self) -> Optional[QWebFrame]");

extern "C" {static PyObject *meth_QWebPage_mainFrame(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_mainFrame(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            ::QWebFrame*sipRes;

            sipRes = sipCpp->mainFrame();

            return sipConvertFromType(sipRes, sipType_QWebFrame, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_mainFrame, doc_QWebPage_mainFrame);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_currentFrame, "currentFrame(self) -> Optional[QWebFrame]");

extern "C" {static PyObject *meth_QWebPage_currentFrame(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_currentFrame(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            ::QWebFrame*sipRes;

            sipRes = sipCpp->currentFrame();

            return sipConvertFromType(sipRes, sipType_QWebFrame, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_currentFrame, doc_QWebPage_currentFrame);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_history, "history(self) -> Optional[QWebHistory]");

extern "C" {static PyObject *meth_QWebPage_history(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_history(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            ::QWebHistory*sipRes;

            sipRes = sipCpp->history();

            return sipConvertFromType(sipRes, sipType_QWebHistory, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_history, doc_QWebPage_history);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_settings, "settings(self) -> Optional[QWebSettings]");

extern "C" {static PyObject *meth_QWebPage_settings(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_settings(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            ::QWebSettings*sipRes;

            sipRes = sipCpp->settings();

            return sipConvertFromType(sipRes, sipType_QWebSettings, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_settings, doc_QWebPage_settings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_setView, "setView(self, view: Optional[QWidget])");

extern "C" {static PyObject *meth_QWebPage_setView(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_setView(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWidget* a0;
        PyObject *a0Keep;
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QWebPage, &sipCpp, &a0Keep, sipType_QWidget, &a0))
        {
            sipCpp->setView(a0);

            sipKeepReference(sipSelf, -3, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_setView, doc_QWebPage_setView);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_view, "view(self) -> Optional[QWidget]");

extern "C" {static PyObject *meth_QWebPage_view(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_view(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            ::QWidget*sipRes;

            sipRes = sipCpp->view();

            return sipConvertFromType(sipRes, sipType_QWidget, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_view, doc_QWebPage_view);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_isModified, "isModified(self) -> bool");

extern "C" {static PyObject *meth_QWebPage_isModified(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_isModified(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isModified();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_isModified, doc_QWebPage_isModified);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_undoStack, "undoStack(self) -> Optional[QUndoStack]");

extern "C" {static PyObject *meth_QWebPage_undoStack(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_undoStack(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            ::QUndoStack*sipRes;

            sipRes = sipCpp->undoStack();

            return sipConvertFromType(sipRes, sipType_QUndoStack, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_undoStack, doc_QWebPage_undoStack);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_setNetworkAccessManager, "setNetworkAccessManager(self, manager: Optional[QNetworkAccessManager])");

extern "C" {static PyObject *meth_QWebPage_setNetworkAccessManager(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_setNetworkAccessManager(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QNetworkAccessManager* a0;
        PyObject *a0Keep;
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QWebPage, &sipCpp, &a0Keep, sipType_QNetworkAccessManager, &a0))
        {
            sipCpp->setNetworkAccessManager(a0);

            sipKeepReference(sipSelf, -4, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_setNetworkAccessManager, doc_QWebPage_setNetworkAccessManager);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_networkAccessManager, "networkAccessManager(self) -> Optional[QNetworkAccessManager]");

extern "C" {static PyObject *meth_QWebPage_networkAccessManager(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_networkAccessManager(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            ::QNetworkAccessManager*sipRes;

            sipRes = sipCpp->networkAccessManager();

            return sipConvertFromType(sipRes, sipType_QNetworkAccessManager, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_networkAccessManager, doc_QWebPage_networkAccessManager);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_setPluginFactory, "setPluginFactory(self, factory: Optional[QWebPluginFactory])");

extern "C" {static PyObject *meth_QWebPage_setPluginFactory(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_setPluginFactory(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebPluginFactory* a0;
        PyObject *a0Keep;
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B@J8", &sipSelf, sipType_QWebPage, &sipCpp, &a0Keep, sipType_QWebPluginFactory, &a0))
        {
            sipCpp->setPluginFactory(a0);

            sipKeepReference(sipSelf, -5, a0Keep);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_setPluginFactory, doc_QWebPage_setPluginFactory);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_pluginFactory, "pluginFactory(self) -> Optional[QWebPluginFactory]");

extern "C" {static PyObject *meth_QWebPage_pluginFactory(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_pluginFactory(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            ::QWebPluginFactory*sipRes;

            sipRes = sipCpp->pluginFactory();

            return sipConvertFromType(sipRes, sipType_QWebPluginFactory, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_pluginFactory, doc_QWebPage_pluginFactory);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_totalBytes, "totalBytes(self) -> int");

extern "C" {static PyObject *meth_QWebPage_totalBytes(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_totalBytes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            ::quint64 sipRes;

            sipRes = sipCpp->totalBytes();

            return PyLong_FromUnsignedLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_totalBytes, doc_QWebPage_totalBytes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_bytesReceived, "bytesReceived(self) -> int");

extern "C" {static PyObject *meth_QWebPage_bytesReceived(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_bytesReceived(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            ::quint64 sipRes;

            sipRes = sipCpp->bytesReceived();

            return PyLong_FromUnsignedLongLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_bytesReceived, doc_QWebPage_bytesReceived);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_selectedText, "selectedText(self) -> str");

extern "C" {static PyObject *meth_QWebPage_selectedText(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_selectedText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->selectedText());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_selectedText, doc_QWebPage_selectedText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_action, "action(self, action: QWebPage.WebAction) -> Optional[QAction]");

extern "C" {static PyObject *meth_QWebPage_action(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_action(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebPage::WebAction a0;
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QWebPage_WebAction, &a0))
        {
            ::QAction*sipRes;

            sipRes = sipCpp->action(a0);

            return sipConvertFromType(sipRes, sipType_QAction, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_action, doc_QWebPage_action);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_triggerAction, "triggerAction(self, action: QWebPage.WebAction, checked: bool = False)");

extern "C" {static PyObject *meth_QWebPage_triggerAction(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWebPage_triggerAction(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWebPage::WebAction a0;
        bool a1 = 0;
        ::QWebPage *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_checked,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|b", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QWebPage_WebAction, &a0, &a1))
        {
            (sipSelfWasArg ? sipCpp->::QWebPage::triggerAction(a0, a1) : sipCpp->triggerAction(a0, a1));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_triggerAction, doc_QWebPage_triggerAction);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_viewportSize, "viewportSize(self) -> QSize");

extern "C" {static PyObject *meth_QWebPage_viewportSize(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_viewportSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize(sipCpp->viewportSize());

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_viewportSize, doc_QWebPage_viewportSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_setViewportSize, "setViewportSize(self, size: QSize)");

extern "C" {static PyObject *meth_QWebPage_setViewportSize(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_setViewportSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSize* a0;
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setViewportSize(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_setViewportSize, doc_QWebPage_setViewportSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_event, "event(self, a0: Optional[QEvent]) -> bool");

extern "C" {static PyObject *meth_QWebPage_event(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_event(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QEvent* a0;
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QEvent, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QWebPage::event(a0) : sipCpp->event(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_event, doc_QWebPage_event);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_focusNextPrevChild, "focusNextPrevChild(self, next: bool) -> bool");

extern "C" {static PyObject *meth_QWebPage_focusNextPrevChild(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_focusNextPrevChild(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QWebPage, &sipCpp, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->focusNextPrevChild(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_focusNextPrevChild, doc_QWebPage_focusNextPrevChild);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_inputMethodQuery, "inputMethodQuery(self, property: Qt.InputMethodQuery) -> Any");

extern "C" {static PyObject *meth_QWebPage_inputMethodQuery(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_inputMethodQuery(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt::InputMethodQuery a0;
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWebPage, &sipCpp, sipType_Qt_InputMethodQuery, &a0))
        {
            ::QVariant*sipRes;

            sipRes = new ::QVariant(sipCpp->inputMethodQuery(a0));

            return sipConvertFromNewType(sipRes, sipType_QVariant, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_inputMethodQuery, doc_QWebPage_inputMethodQuery);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_findText, "findText(self, subString: Optional[str], options: QWebPage.FindFlags = 0) -> bool");

extern "C" {static PyObject *meth_QWebPage_findText(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWebPage_findText(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QWebPage::FindFlags a1def = 0;
        ::QWebPage::FindFlags* a1 = &a1def;
        int a1State = 0;
        ::QWebPage *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_options,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BJ1|J1", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QString, &a0, &a0State, sipType_QWebPage_FindFlags, &a1, &a1State))
        {
            bool sipRes;

            sipRes = sipCpp->findText(*a0, *a1);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(a1, sipType_QWebPage_FindFlags, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_findText, doc_QWebPage_findText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_setForwardUnsupportedContent, "setForwardUnsupportedContent(self, forward: bool)");

extern "C" {static PyObject *meth_QWebPage_setForwardUnsupportedContent(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_setForwardUnsupportedContent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QWebPage, &sipCpp, &a0))
        {
            sipCpp->setForwardUnsupportedContent(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_setForwardUnsupportedContent, doc_QWebPage_setForwardUnsupportedContent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_forwardUnsupportedContent, "forwardUnsupportedContent(self) -> bool");

extern "C" {static PyObject *meth_QWebPage_forwardUnsupportedContent(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_forwardUnsupportedContent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->forwardUnsupportedContent();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_forwardUnsupportedContent, doc_QWebPage_forwardUnsupportedContent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_setLinkDelegationPolicy, "setLinkDelegationPolicy(self, policy: QWebPage.LinkDelegationPolicy)");

extern "C" {static PyObject *meth_QWebPage_setLinkDelegationPolicy(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_setLinkDelegationPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebPage::LinkDelegationPolicy a0;
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QWebPage_LinkDelegationPolicy, &a0))
        {
            sipCpp->setLinkDelegationPolicy(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_setLinkDelegationPolicy, doc_QWebPage_setLinkDelegationPolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_linkDelegationPolicy, "linkDelegationPolicy(self) -> QWebPage.LinkDelegationPolicy");

extern "C" {static PyObject *meth_QWebPage_linkDelegationPolicy(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_linkDelegationPolicy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            ::QWebPage::LinkDelegationPolicy sipRes;

            sipRes = sipCpp->linkDelegationPolicy();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QWebPage_LinkDelegationPolicy);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_linkDelegationPolicy, doc_QWebPage_linkDelegationPolicy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_setPalette, "setPalette(self, palette: QPalette)");

extern "C" {static PyObject *meth_QWebPage_setPalette(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_setPalette(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPalette* a0;
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QPalette, &a0))
        {
            sipCpp->setPalette(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_setPalette, doc_QWebPage_setPalette);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_palette, "palette(self) -> QPalette");

extern "C" {static PyObject *meth_QWebPage_palette(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_palette(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            ::QPalette*sipRes;

            sipRes = new ::QPalette(sipCpp->palette());

            return sipConvertFromNewType(sipRes, sipType_QPalette, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_palette, doc_QWebPage_palette);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_swallowContextMenuEvent, "swallowContextMenuEvent(self, event: Optional[QContextMenuEvent]) -> bool");

extern "C" {static PyObject *meth_QWebPage_swallowContextMenuEvent(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_swallowContextMenuEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QContextMenuEvent* a0;
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QContextMenuEvent, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->swallowContextMenuEvent(a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_swallowContextMenuEvent, doc_QWebPage_swallowContextMenuEvent);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_updatePositionDependentActions, "updatePositionDependentActions(self, pos: QPoint)");

extern "C" {static PyObject *meth_QWebPage_updatePositionDependentActions(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_updatePositionDependentActions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPoint* a0;
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QPoint, &a0))
        {
            sipCpp->updatePositionDependentActions(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_updatePositionDependentActions, doc_QWebPage_updatePositionDependentActions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_extension, "extension(self, extension: QWebPage.Extension, option: Optional[QWebPage.ExtensionOption] = None, output: Optional[QWebPage.ExtensionReturn] = None) -> bool");

extern "C" {static PyObject *meth_QWebPage_extension(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QWebPage_extension(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWebPage::Extension a0;
        const ::QWebPage::ExtensionOption* a1 = 0;
        ::QWebPage::ExtensionReturn* a2 = 0;
        ::QWebPage *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_option,
            sipName_output,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "BE|J8J8", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QWebPage_Extension, &a0, sipType_QWebPage_ExtensionOption, &a1, sipType_QWebPage_ExtensionReturn, &a2))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QWebPage::extension(a0, a1, a2) : sipCpp->extension(a0, a1, a2));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_extension, doc_QWebPage_extension);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_supportsExtension, "supportsExtension(self, extension: QWebPage.Extension) -> bool");

extern "C" {static PyObject *meth_QWebPage_supportsExtension(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_supportsExtension(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWebPage::Extension a0;
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QWebPage_Extension, &a0))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QWebPage::supportsExtension(a0) : sipCpp->supportsExtension(a0));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_supportsExtension, doc_QWebPage_supportsExtension);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_createWindow, "createWindow(self, type: QWebPage.WebWindowType) -> Optional[QWebPage]");

extern "C" {static PyObject *meth_QWebPage_createWindow(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_createWindow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWebPage::WebWindowType a0;
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pE", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QWebPage_WebWindowType, &a0))
        {
            ::QWebPage*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QWebPage::createWindow(a0) : sipCpp->createWindow(a0));

            return sipConvertFromType(sipRes, sipType_QWebPage, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_createWindow, doc_QWebPage_createWindow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_createPlugin, "createPlugin(self, classid: Optional[str], url: QUrl, paramNames: Iterable[Optional[str]], paramValues: Iterable[Optional[str]]) -> Optional[QObject]");

extern "C" {static PyObject *meth_QWebPage_createPlugin(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_createPlugin(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QUrl* a1;
        const ::QStringList* a2;
        int a2State = 0;
        const ::QStringList* a3;
        int a3State = 0;
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1J9J1J1", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QString, &a0, &a0State, sipType_QUrl, &a1, sipType_QStringList, &a2, &a2State, sipType_QStringList, &a3, &a3State))
        {
            ::QObject*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QWebPage::createPlugin(*a0, *a1, *a2, *a3) : sipCpp->createPlugin(*a0, *a1, *a2, *a3));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QStringList *>(a2), sipType_QStringList, a2State);
            sipReleaseType(const_cast< ::QStringList *>(a3), sipType_QStringList, a3State);

            return sipConvertFromType(sipRes, sipType_QObject, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_createPlugin, doc_QWebPage_createPlugin);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_acceptNavigationRequest, "acceptNavigationRequest(self, frame: Optional[QWebFrame], request: QNetworkRequest, type: QWebPage.NavigationType) -> bool");

extern "C" {static PyObject *meth_QWebPage_acceptNavigationRequest(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_acceptNavigationRequest(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWebFrame* a0;
        const ::QNetworkRequest* a1;
        ::QWebPage::NavigationType a2;
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8J9E", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QWebFrame, &a0, sipType_QNetworkRequest, &a1, sipType_QWebPage_NavigationType, &a2))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QWebPage::acceptNavigationRequest(a0, *a1, a2) : sipCpp->acceptNavigationRequest(a0, *a1, a2));

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_acceptNavigationRequest, doc_QWebPage_acceptNavigationRequest);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_chooseFile, "chooseFile(self, originatingFrame: Optional[QWebFrame], oldFile: Optional[str]) -> str");

extern "C" {static PyObject *meth_QWebPage_chooseFile(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_chooseFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWebFrame* a0;
        const ::QString* a1;
        int a1State = 0;
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8J1", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QWebFrame, &a0, sipType_QString, &a1, &a1State))
        {
            ::QString*sipRes;

            sipRes = new ::QString((sipSelfWasArg ? sipCpp->::QWebPage::chooseFile(a0, *a1) : sipCpp->chooseFile(a0, *a1)));
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_chooseFile, doc_QWebPage_chooseFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_javaScriptAlert, "javaScriptAlert(self, originatingFrame: Optional[QWebFrame], msg: Optional[str])");

extern "C" {static PyObject *meth_QWebPage_javaScriptAlert(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_javaScriptAlert(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWebFrame* a0;
        const ::QString* a1;
        int a1State = 0;
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8J1", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QWebFrame, &a0, sipType_QString, &a1, &a1State))
        {
            (sipSelfWasArg ? sipCpp->::QWebPage::javaScriptAlert(a0, *a1) : sipCpp->javaScriptAlert(a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_javaScriptAlert, doc_QWebPage_javaScriptAlert);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_javaScriptConfirm, "javaScriptConfirm(self, originatingFrame: Optional[QWebFrame], msg: Optional[str]) -> bool");

extern "C" {static PyObject *meth_QWebPage_javaScriptConfirm(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_javaScriptConfirm(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWebFrame* a0;
        const ::QString* a1;
        int a1State = 0;
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8J1", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QWebFrame, &a0, sipType_QString, &a1, &a1State))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QWebPage::javaScriptConfirm(a0, *a1) : sipCpp->javaScriptConfirm(a0, *a1));
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_javaScriptConfirm, doc_QWebPage_javaScriptConfirm);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_javaScriptPrompt, "javaScriptPrompt(self, originatingFrame: Optional[QWebFrame], msg: Optional[str], defaultValue: Optional[str]) -> (bool, Optional[str])");

extern "C" {static PyObject *meth_QWebPage_javaScriptPrompt(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_javaScriptPrompt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWebFrame* a0;
        const ::QString* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        ::QString* a3;
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ8J1J1", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QWebFrame, &a0, sipType_QString, &a1, &a1State, sipType_QString, &a2, &a2State))
        {
            bool sipRes;
            a3 = new ::QString();

            sipRes = (sipSelfWasArg ? sipCpp->::QWebPage::javaScriptPrompt(a0, *a1, *a2, a3) : sipCpp->javaScriptPrompt(a0, *a1, *a2, a3));
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);

            return sipBuildResult(0, "(bN)", sipRes, a3, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_javaScriptPrompt, doc_QWebPage_javaScriptPrompt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_javaScriptConsoleMessage, "javaScriptConsoleMessage(self, message: Optional[str], lineNumber: int, sourceID: Optional[str])");

extern "C" {static PyObject *meth_QWebPage_javaScriptConsoleMessage(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_javaScriptConsoleMessage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QString* a0;
        int a0State = 0;
        int a1;
        const ::QString* a2;
        int a2State = 0;
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ1iJ1", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QString, &a0, &a0State, &a1, sipType_QString, &a2, &a2State))
        {
            (sipSelfWasArg ? sipCpp->::QWebPage::javaScriptConsoleMessage(*a0, a1, *a2) : sipCpp->javaScriptConsoleMessage(*a0, a1, *a2));
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_javaScriptConsoleMessage, doc_QWebPage_javaScriptConsoleMessage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_userAgentForUrl, "userAgentForUrl(self, url: QUrl) -> str");

extern "C" {static PyObject *meth_QWebPage_userAgentForUrl(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_userAgentForUrl(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QUrl* a0;
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QUrl, &a0))
        {
            ::QString*sipRes;

            sipRes = new ::QString((sipSelfWasArg ? sipCpp->::QWebPage::userAgentForUrl(*a0) : sipCpp->userAgentForUrl(*a0)));

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_userAgentForUrl, doc_QWebPage_userAgentForUrl);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_setContentEditable, "setContentEditable(self, editable: bool)");

extern "C" {static PyObject *meth_QWebPage_setContentEditable(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_setContentEditable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QWebPage, &sipCpp, &a0))
        {
            sipCpp->setContentEditable(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_setContentEditable, doc_QWebPage_setContentEditable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_isContentEditable, "isContentEditable(self) -> bool");

extern "C" {static PyObject *meth_QWebPage_isContentEditable(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_isContentEditable(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isContentEditable();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_isContentEditable, doc_QWebPage_isContentEditable);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_createStandardContextMenu, "createStandardContextMenu(self) -> Optional[QMenu]");

extern "C" {static PyObject *meth_QWebPage_createStandardContextMenu(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_createStandardContextMenu(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            ::QMenu*sipRes;

            sipRes = sipCpp->createStandardContextMenu();

            return sipConvertFromNewType(sipRes, sipType_QMenu, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_createStandardContextMenu, doc_QWebPage_createStandardContextMenu);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_frameAt, "frameAt(self, pos: QPoint) -> Optional[QWebFrame]");

extern "C" {static PyObject *meth_QWebPage_frameAt(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_frameAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPoint* a0;
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QPoint, &a0))
        {
            ::QWebFrame*sipRes;

            sipRes = sipCpp->frameAt(*a0);

            return sipConvertFromType(sipRes, sipType_QWebFrame, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_frameAt, doc_QWebPage_frameAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_preferredContentsSize, "preferredContentsSize(self) -> QSize");

extern "C" {static PyObject *meth_QWebPage_preferredContentsSize(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_preferredContentsSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            ::QSize*sipRes;

            sipRes = new ::QSize(sipCpp->preferredContentsSize());

            return sipConvertFromNewType(sipRes, sipType_QSize, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_preferredContentsSize, doc_QWebPage_preferredContentsSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_setPreferredContentsSize, "setPreferredContentsSize(self, size: QSize)");

extern "C" {static PyObject *meth_QWebPage_setPreferredContentsSize(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_setPreferredContentsSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSize* a0;
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QSize, &a0))
        {
            sipCpp->setPreferredContentsSize(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_setPreferredContentsSize, doc_QWebPage_setPreferredContentsSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_shouldInterruptJavaScript, "shouldInterruptJavaScript(self) -> bool");

extern "C" {static PyObject *meth_QWebPage_shouldInterruptJavaScript(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_shouldInterruptJavaScript(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            bool sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QWebPage::shouldInterruptJavaScript() : sipCpp->shouldInterruptJavaScript());

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_shouldInterruptJavaScript, doc_QWebPage_shouldInterruptJavaScript);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_hasSelection, "hasSelection(self) -> bool");

extern "C" {static PyObject *meth_QWebPage_hasSelection(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_hasSelection(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->hasSelection();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_hasSelection, doc_QWebPage_hasSelection);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_selectedHtml, "selectedHtml(self) -> str");

extern "C" {static PyObject *meth_QWebPage_selectedHtml(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_selectedHtml(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->selectedHtml());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_selectedHtml, doc_QWebPage_selectedHtml);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_viewportAttributesForSize, "viewportAttributesForSize(self, availableSize: QSize) -> QWebPage.ViewportAttributes");

extern "C" {static PyObject *meth_QWebPage_viewportAttributesForSize(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_viewportAttributesForSize(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QSize* a0;
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QSize, &a0))
        {
            ::QWebPage::ViewportAttributes*sipRes;

            sipRes = new ::QWebPage::ViewportAttributes(sipCpp->viewportAttributesForSize(*a0));

            return sipConvertFromNewType(sipRes, sipType_QWebPage_ViewportAttributes, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_viewportAttributesForSize, doc_QWebPage_viewportAttributesForSize);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_setActualVisibleContentRect, "setActualVisibleContentRect(self, rect: QRect)");

extern "C" {static PyObject *meth_QWebPage_setActualVisibleContentRect(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_setActualVisibleContentRect(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRect* a0;
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QRect, &a0))
        {
            sipCpp->setActualVisibleContentRect(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_setActualVisibleContentRect, doc_QWebPage_setActualVisibleContentRect);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_setFeaturePermission, "setFeaturePermission(self, frame: Optional[QWebFrame], feature: QWebPage.Feature, policy: QWebPage.PermissionPolicy)");

extern "C" {static PyObject *meth_QWebPage_setFeaturePermission(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_setFeaturePermission(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebFrame* a0;
        ::QWebPage::Feature a1;
        ::QWebPage::PermissionPolicy a2;
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8EE", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QWebFrame, &a0, sipType_QWebPage_Feature, &a1, sipType_QWebPage_PermissionPolicy, &a2))
        {
            sipCpp->setFeaturePermission(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_setFeaturePermission, doc_QWebPage_setFeaturePermission);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_supportedContentTypes, "supportedContentTypes(self) -> list[str]");

extern "C" {static PyObject *meth_QWebPage_supportedContentTypes(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_supportedContentTypes(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->supportedContentTypes());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_supportedContentTypes, doc_QWebPage_supportedContentTypes);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_supportsContentType, "supportsContentType(self, mimeType: Optional[str]) -> bool");

extern "C" {static PyObject *meth_QWebPage_supportsContentType(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_supportsContentType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QString, &a0, &a0State))
        {
            bool sipRes;

            sipRes = sipCpp->supportsContentType(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_supportsContentType, doc_QWebPage_supportsContentType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_visibilityState, "visibilityState(self) -> QWebPage.VisibilityState");

extern "C" {static PyObject *meth_QWebPage_visibilityState(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_visibilityState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QWebPage, &sipCpp))
        {
            ::QWebPage::VisibilityState sipRes;

            sipRes = sipCpp->visibilityState();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QWebPage_VisibilityState);
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_visibilityState, doc_QWebPage_visibilityState);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QWebPage_setVisibilityState, "setVisibilityState(self, a0: QWebPage.VisibilityState)");

extern "C" {static PyObject *meth_QWebPage_setVisibilityState(PyObject *, PyObject *);}
static PyObject *meth_QWebPage_setVisibilityState(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QWebPage::VisibilityState a0;
        ::QWebPage *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QWebPage, &sipCpp, sipType_QWebPage_VisibilityState, &a0))
        {
            sipCpp->setVisibilityState(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QWebPage, sipName_setVisibilityState, doc_QWebPage_setVisibilityState);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QWebPage(void *, const sipTypeDef *);}
static void *cast_QWebPage(void *sipCppV, const sipTypeDef *targetType)
{
    ::QWebPage *sipCpp = reinterpret_cast< ::QWebPage *>(sipCppV);

    if (targetType == sipType_QWebPage)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QWebPage(void *, int);}
static void release_QWebPage(void *sipCppV, int)
{
    ::QWebPage *sipCpp = reinterpret_cast< ::QWebPage *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QWebPage(Py_ssize_t);}
static void *array_QWebPage(Py_ssize_t sipNrElem)
{
    return new ::QWebPage[sipNrElem];
}


extern "C" {static void array_delete_QWebPage(void *);}
static void array_delete_QWebPage(void *sipCpp)
{
    delete[] reinterpret_cast< ::QWebPage *>(sipCpp);
}


extern "C" {static void dealloc_QWebPage(sipSimpleWrapper *);}
static void dealloc_QWebPage(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQWebPage *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QWebPage(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QWebPage(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QWebPage(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQWebPage *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQWebPage(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QWebPage[] = {{4, 0, 1}};


static PyMethodDef methods_QWebPage[] = {
    {sipName_acceptNavigationRequest, meth_QWebPage_acceptNavigationRequest, METH_VARARGS, doc_QWebPage_acceptNavigationRequest},
    {sipName_action, meth_QWebPage_action, METH_VARARGS, doc_QWebPage_action},
    {sipName_bytesReceived, meth_QWebPage_bytesReceived, METH_VARARGS, doc_QWebPage_bytesReceived},
    {sipName_chooseFile, meth_QWebPage_chooseFile, METH_VARARGS, doc_QWebPage_chooseFile},
    {sipName_createPlugin, meth_QWebPage_createPlugin, METH_VARARGS, doc_QWebPage_createPlugin},
    {sipName_createStandardContextMenu, meth_QWebPage_createStandardContextMenu, METH_VARARGS, doc_QWebPage_createStandardContextMenu},
    {sipName_createWindow, meth_QWebPage_createWindow, METH_VARARGS, doc_QWebPage_createWindow},
    {sipName_currentFrame, meth_QWebPage_currentFrame, METH_VARARGS, doc_QWebPage_currentFrame},
    {sipName_event, meth_QWebPage_event, METH_VARARGS, doc_QWebPage_event},
    {sipName_extension, SIP_MLMETH_CAST(meth_QWebPage_extension), METH_VARARGS|METH_KEYWORDS, doc_QWebPage_extension},
    {sipName_findText, SIP_MLMETH_CAST(meth_QWebPage_findText), METH_VARARGS|METH_KEYWORDS, doc_QWebPage_findText},
    {sipName_focusNextPrevChild, meth_QWebPage_focusNextPrevChild, METH_VARARGS, doc_QWebPage_focusNextPrevChild},
    {sipName_forwardUnsupportedContent, meth_QWebPage_forwardUnsupportedContent, METH_VARARGS, doc_QWebPage_forwardUnsupportedContent},
    {sipName_frameAt, meth_QWebPage_frameAt, METH_VARARGS, doc_QWebPage_frameAt},
    {sipName_hasSelection, meth_QWebPage_hasSelection, METH_VARARGS, doc_QWebPage_hasSelection},
    {sipName_history, meth_QWebPage_history, METH_VARARGS, doc_QWebPage_history},
    {sipName_inputMethodQuery, meth_QWebPage_inputMethodQuery, METH_VARARGS, doc_QWebPage_inputMethodQuery},
    {sipName_isContentEditable, meth_QWebPage_isContentEditable, METH_VARARGS, doc_QWebPage_isContentEditable},
    {sipName_isModified, meth_QWebPage_isModified, METH_VARARGS, doc_QWebPage_isModified},
    {sipName_javaScriptAlert, meth_QWebPage_javaScriptAlert, METH_VARARGS, doc_QWebPage_javaScriptAlert},
    {sipName_javaScriptConfirm, meth_QWebPage_javaScriptConfirm, METH_VARARGS, doc_QWebPage_javaScriptConfirm},
    {sipName_javaScriptConsoleMessage, meth_QWebPage_javaScriptConsoleMessage, METH_VARARGS, doc_QWebPage_javaScriptConsoleMessage},
    {sipName_javaScriptPrompt, meth_QWebPage_javaScriptPrompt, METH_VARARGS, doc_QWebPage_javaScriptPrompt},
    {sipName_linkDelegationPolicy, meth_QWebPage_linkDelegationPolicy, METH_VARARGS, doc_QWebPage_linkDelegationPolicy},
    {sipName_mainFrame, meth_QWebPage_mainFrame, METH_VARARGS, doc_QWebPage_mainFrame},
    {sipName_networkAccessManager, meth_QWebPage_networkAccessManager, METH_VARARGS, doc_QWebPage_networkAccessManager},
    {sipName_palette, meth_QWebPage_palette, METH_VARARGS, doc_QWebPage_palette},
    {sipName_pluginFactory, meth_QWebPage_pluginFactory, METH_VARARGS, doc_QWebPage_pluginFactory},
    {sipName_preferredContentsSize, meth_QWebPage_preferredContentsSize, METH_VARARGS, doc_QWebPage_preferredContentsSize},
    {sipName_selectedHtml, meth_QWebPage_selectedHtml, METH_VARARGS, doc_QWebPage_selectedHtml},
    {sipName_selectedText, meth_QWebPage_selectedText, METH_VARARGS, doc_QWebPage_selectedText},
    {sipName_setActualVisibleContentRect, meth_QWebPage_setActualVisibleContentRect, METH_VARARGS, doc_QWebPage_setActualVisibleContentRect},
    {sipName_setContentEditable, meth_QWebPage_setContentEditable, METH_VARARGS, doc_QWebPage_setContentEditable},
    {sipName_setFeaturePermission, meth_QWebPage_setFeaturePermission, METH_VARARGS, doc_QWebPage_setFeaturePermission},
    {sipName_setForwardUnsupportedContent, meth_QWebPage_setForwardUnsupportedContent, METH_VARARGS, doc_QWebPage_setForwardUnsupportedContent},
    {sipName_setLinkDelegationPolicy, meth_QWebPage_setLinkDelegationPolicy, METH_VARARGS, doc_QWebPage_setLinkDelegationPolicy},
    {sipName_setNetworkAccessManager, meth_QWebPage_setNetworkAccessManager, METH_VARARGS, doc_QWebPage_setNetworkAccessManager},
    {sipName_setPalette, meth_QWebPage_setPalette, METH_VARARGS, doc_QWebPage_setPalette},
    {sipName_setPluginFactory, meth_QWebPage_setPluginFactory, METH_VARARGS, doc_QWebPage_setPluginFactory},
    {sipName_setPreferredContentsSize, meth_QWebPage_setPreferredContentsSize, METH_VARARGS, doc_QWebPage_setPreferredContentsSize},
    {sipName_setView, meth_QWebPage_setView, METH_VARARGS, doc_QWebPage_setView},
    {sipName_setViewportSize, meth_QWebPage_setViewportSize, METH_VARARGS, doc_QWebPage_setViewportSize},
    {sipName_setVisibilityState, meth_QWebPage_setVisibilityState, METH_VARARGS, doc_QWebPage_setVisibilityState},
    {sipName_settings, meth_QWebPage_settings, METH_VARARGS, doc_QWebPage_settings},
    {sipName_shouldInterruptJavaScript, meth_QWebPage_shouldInterruptJavaScript, METH_VARARGS, doc_QWebPage_shouldInterruptJavaScript},
    {sipName_supportedContentTypes, meth_QWebPage_supportedContentTypes, METH_VARARGS, doc_QWebPage_supportedContentTypes},
    {sipName_supportsContentType, meth_QWebPage_supportsContentType, METH_VARARGS, doc_QWebPage_supportsContentType},
    {sipName_supportsExtension, meth_QWebPage_supportsExtension, METH_VARARGS, doc_QWebPage_supportsExtension},
    {sipName_swallowContextMenuEvent, meth_QWebPage_swallowContextMenuEvent, METH_VARARGS, doc_QWebPage_swallowContextMenuEvent},
    {sipName_totalBytes, meth_QWebPage_totalBytes, METH_VARARGS, doc_QWebPage_totalBytes},
    {sipName_triggerAction, SIP_MLMETH_CAST(meth_QWebPage_triggerAction), METH_VARARGS|METH_KEYWORDS, doc_QWebPage_triggerAction},
    {sipName_undoStack, meth_QWebPage_undoStack, METH_VARARGS, doc_QWebPage_undoStack},
    {sipName_updatePositionDependentActions, meth_QWebPage_updatePositionDependentActions, METH_VARARGS, doc_QWebPage_updatePositionDependentActions},
    {sipName_userAgentForUrl, meth_QWebPage_userAgentForUrl, METH_VARARGS, doc_QWebPage_userAgentForUrl},
    {sipName_view, meth_QWebPage_view, METH_VARARGS, doc_QWebPage_view},
    {sipName_viewportAttributesForSize, meth_QWebPage_viewportAttributesForSize, METH_VARARGS, doc_QWebPage_viewportAttributesForSize},
    {sipName_viewportSize, meth_QWebPage_viewportSize, METH_VARARGS, doc_QWebPage_viewportSize},
    {sipName_visibilityState, meth_QWebPage_visibilityState, METH_VARARGS, doc_QWebPage_visibilityState}
};

static sipEnumMemberDef enummembers_QWebPage[] = {
    {sipName_AlignCenter, static_cast<int>(::QWebPage::AlignCenter), 26},
    {sipName_AlignJustified, static_cast<int>(::QWebPage::AlignJustified), 26},
    {sipName_AlignLeft, static_cast<int>(::QWebPage::AlignLeft), 26},
    {sipName_AlignRight, static_cast<int>(::QWebPage::AlignRight), 26},
    {sipName_Back, static_cast<int>(::QWebPage::Back), 26},
    {sipName_ChooseMultipleFilesExtension, static_cast<int>(::QWebPage::ChooseMultipleFilesExtension), 15},
    {sipName_Copy, static_cast<int>(::QWebPage::Copy), 26},
    {sipName_CopyImageToClipboard, static_cast<int>(::QWebPage::CopyImageToClipboard), 26},
    {sipName_CopyImageUrlToClipboard, static_cast<int>(::QWebPage::CopyImageUrlToClipboard), 26},
    {sipName_CopyLinkToClipboard, static_cast<int>(::QWebPage::CopyLinkToClipboard), 26},
    {sipName_CopyMediaUrlToClipboard, static_cast<int>(::QWebPage::CopyMediaUrlToClipboard), 26},
    {sipName_Cut, static_cast<int>(::QWebPage::Cut), 26},
    {sipName_DelegateAllLinks, static_cast<int>(::QWebPage::DelegateAllLinks), 21},
    {sipName_DelegateExternalLinks, static_cast<int>(::QWebPage::DelegateExternalLinks), 21},
    {sipName_DeleteEndOfWord, static_cast<int>(::QWebPage::DeleteEndOfWord), 26},
    {sipName_DeleteStartOfWord, static_cast<int>(::QWebPage::DeleteStartOfWord), 26},
    {sipName_DontDelegateLinks, static_cast<int>(::QWebPage::DontDelegateLinks), 21},
    {sipName_DownloadImageToDisk, static_cast<int>(::QWebPage::DownloadImageToDisk), 26},
    {sipName_DownloadLinkToDisk, static_cast<int>(::QWebPage::DownloadLinkToDisk), 26},
    {sipName_DownloadMediaToDisk, static_cast<int>(::QWebPage::DownloadMediaToDisk), 26},
    {sipName_ErrorPageExtension, static_cast<int>(::QWebPage::ErrorPageExtension), 15},
    {sipName_FindAtWordBeginningsOnly, static_cast<int>(::QWebPage::FindAtWordBeginningsOnly), 19},
    {sipName_FindBackward, static_cast<int>(::QWebPage::FindBackward), 19},
    {sipName_FindBeginsInSelection, static_cast<int>(::QWebPage::FindBeginsInSelection), 19},
    {sipName_FindCaseSensitively, static_cast<int>(::QWebPage::FindCaseSensitively), 19},
    {sipName_FindWrapsAroundDocument, static_cast<int>(::QWebPage::FindWrapsAroundDocument), 19},
    {sipName_Forward, static_cast<int>(::QWebPage::Forward), 26},
    {sipName_Geolocation, static_cast<int>(::QWebPage::Geolocation), 18},
    {sipName_HighlightAllOccurrences, static_cast<int>(::QWebPage::HighlightAllOccurrences), 19},
    {sipName_Http, static_cast<int>(::QWebPage::Http), 12},
    {sipName_Indent, static_cast<int>(::QWebPage::Indent), 26},
    {sipName_InsertLineSeparator, static_cast<int>(::QWebPage::InsertLineSeparator), 26},
    {sipName_InsertOrderedList, static_cast<int>(::QWebPage::InsertOrderedList), 26},
    {sipName_InsertParagraphSeparator, static_cast<int>(::QWebPage::InsertParagraphSeparator), 26},
    {sipName_InsertUnorderedList, static_cast<int>(::QWebPage::InsertUnorderedList), 26},
    {sipName_InspectElement, static_cast<int>(::QWebPage::InspectElement), 26},
    {sipName_MoveToEndOfBlock, static_cast<int>(::QWebPage::MoveToEndOfBlock), 26},
    {sipName_MoveToEndOfDocument, static_cast<int>(::QWebPage::MoveToEndOfDocument), 26},
    {sipName_MoveToEndOfLine, static_cast<int>(::QWebPage::MoveToEndOfLine), 26},
    {sipName_MoveToNextChar, static_cast<int>(::QWebPage::MoveToNextChar), 26},
    {sipName_MoveToNextLine, static_cast<int>(::QWebPage::MoveToNextLine), 26},
    {sipName_MoveToNextWord, static_cast<int>(::QWebPage::MoveToNextWord), 26},
    {sipName_MoveToPreviousChar, static_cast<int>(::QWebPage::MoveToPreviousChar), 26},
    {sipName_MoveToPreviousLine, static_cast<int>(::QWebPage::MoveToPreviousLine), 26},
    {sipName_MoveToPreviousWord, static_cast<int>(::QWebPage::MoveToPreviousWord), 26},
    {sipName_MoveToStartOfBlock, static_cast<int>(::QWebPage::MoveToStartOfBlock), 26},
    {sipName_MoveToStartOfDocument, static_cast<int>(::QWebPage::MoveToStartOfDocument), 26},
    {sipName_MoveToStartOfLine, static_cast<int>(::QWebPage::MoveToStartOfLine), 26},
    {sipName_NavigationTypeBackOrForward, static_cast<int>(::QWebPage::NavigationTypeBackOrForward), 22},
    {sipName_NavigationTypeFormResubmitted, static_cast<int>(::QWebPage::NavigationTypeFormResubmitted), 22},
    {sipName_NavigationTypeFormSubmitted, static_cast<int>(::QWebPage::NavigationTypeFormSubmitted), 22},
    {sipName_NavigationTypeLinkClicked, static_cast<int>(::QWebPage::NavigationTypeLinkClicked), 22},
    {sipName_NavigationTypeOther, static_cast<int>(::QWebPage::NavigationTypeOther), 22},
    {sipName_NavigationTypeReload, static_cast<int>(::QWebPage::NavigationTypeReload), 22},
    {sipName_NoWebAction, static_cast<int>(::QWebPage::NoWebAction), 26},
    {sipName_Notifications, static_cast<int>(::QWebPage::Notifications), 18},
    {sipName_OpenFrameInNewWindow, static_cast<int>(::QWebPage::OpenFrameInNewWindow), 26},
    {sipName_OpenImageInNewWindow, static_cast<int>(::QWebPage::OpenImageInNewWindow), 26},
    {sipName_OpenLink, static_cast<int>(::QWebPage::OpenLink), 26},
    {sipName_OpenLinkInNewWindow, static_cast<int>(::QWebPage::OpenLinkInNewWindow), 26},
    {sipName_OpenLinkInThisWindow, static_cast<int>(::QWebPage::OpenLinkInThisWindow), 26},
    {sipName_Outdent, static_cast<int>(::QWebPage::Outdent), 26},
    {sipName_Paste, static_cast<int>(::QWebPage::Paste), 26},
    {sipName_PasteAndMatchStyle, static_cast<int>(::QWebPage::PasteAndMatchStyle), 26},
    {sipName_PermissionDeniedByUser, static_cast<int>(::QWebPage::PermissionDeniedByUser), 23},
    {sipName_PermissionGrantedByUser, static_cast<int>(::QWebPage::PermissionGrantedByUser), 23},
    {sipName_PermissionUnknown, static_cast<int>(::QWebPage::PermissionUnknown), 23},
    {sipName_QtNetwork, static_cast<int>(::QWebPage::QtNetwork), 12},
    {sipName_Redo, static_cast<int>(::QWebPage::Redo), 26},
    {sipName_Reload, static_cast<int>(::QWebPage::Reload), 26},
    {sipName_ReloadAndBypassCache, static_cast<int>(::QWebPage::ReloadAndBypassCache), 26},
    {sipName_RemoveFormat, static_cast<int>(::QWebPage::RemoveFormat), 26},
    {sipName_SelectAll, static_cast<int>(::QWebPage::SelectAll), 26},
    {sipName_SelectEndOfBlock, static_cast<int>(::QWebPage::SelectEndOfBlock), 26},
    {sipName_SelectEndOfDocument, static_cast<int>(::QWebPage::SelectEndOfDocument), 26},
    {sipName_SelectEndOfLine, static_cast<int>(::QWebPage::SelectEndOfLine), 26},
    {sipName_SelectNextChar, static_cast<int>(::QWebPage::SelectNextChar), 26},
    {sipName_SelectNextLine, static_cast<int>(::QWebPage::SelectNextLine), 26},
    {sipName_SelectNextWord, static_cast<int>(::QWebPage::SelectNextWord), 26},
    {sipName_SelectPreviousChar, static_cast<int>(::QWebPage::SelectPreviousChar), 26},
    {sipName_SelectPreviousLine, static_cast<int>(::QWebPage::SelectPreviousLine), 26},
    {sipName_SelectPreviousWord, static_cast<int>(::QWebPage::SelectPreviousWord), 26},
    {sipName_SelectStartOfBlock, static_cast<int>(::QWebPage::SelectStartOfBlock), 26},
    {sipName_SelectStartOfDocument, static_cast<int>(::QWebPage::SelectStartOfDocument), 26},
    {sipName_SelectStartOfLine, static_cast<int>(::QWebPage::SelectStartOfLine), 26},
    {sipName_SetTextDirectionDefault, static_cast<int>(::QWebPage::SetTextDirectionDefault), 26},
    {sipName_SetTextDirectionLeftToRight, static_cast<int>(::QWebPage::SetTextDirectionLeftToRight), 26},
    {sipName_SetTextDirectionRightToLeft, static_cast<int>(::QWebPage::SetTextDirectionRightToLeft), 26},
    {sipName_Stop, static_cast<int>(::QWebPage::Stop), 26},
    {sipName_StopScheduledPageRefresh, static_cast<int>(::QWebPage::StopScheduledPageRefresh), 26},
    {sipName_ToggleBold, static_cast<int>(::QWebPage::ToggleBold), 26},
    {sipName_ToggleItalic, static_cast<int>(::QWebPage::ToggleItalic), 26},
    {sipName_ToggleMediaControls, static_cast<int>(::QWebPage::ToggleMediaControls), 26},
    {sipName_ToggleMediaLoop, static_cast<int>(::QWebPage::ToggleMediaLoop), 26},
    {sipName_ToggleMediaMute, static_cast<int>(::QWebPage::ToggleMediaMute), 26},
    {sipName_ToggleMediaPlayPause, static_cast<int>(::QWebPage::ToggleMediaPlayPause), 26},
    {sipName_ToggleStrikethrough, static_cast<int>(::QWebPage::ToggleStrikethrough), 26},
    {sipName_ToggleSubscript, static_cast<int>(::QWebPage::ToggleSubscript), 26},
    {sipName_ToggleSuperscript, static_cast<int>(::QWebPage::ToggleSuperscript), 26},
    {sipName_ToggleUnderline, static_cast<int>(::QWebPage::ToggleUnderline), 26},
    {sipName_ToggleVideoFullscreen, static_cast<int>(::QWebPage::ToggleVideoFullscreen), 26},
    {sipName_TreatMedialCapitalAsWordBeginning, static_cast<int>(::QWebPage::TreatMedialCapitalAsWordBeginning), 19},
    {sipName_Undo, static_cast<int>(::QWebPage::Undo), 26},
    {sipName_VisibilityStateHidden, static_cast<int>(::QWebPage::VisibilityStateHidden), 25},
    {sipName_VisibilityStatePrerender, static_cast<int>(::QWebPage::VisibilityStatePrerender), 25},
    {sipName_VisibilityStateUnloaded, static_cast<int>(::QWebPage::VisibilityStateUnloaded), 25},
    {sipName_VisibilityStateVisible, static_cast<int>(::QWebPage::VisibilityStateVisible), 25},
    {sipName_WebBrowserWindow, static_cast<int>(::QWebPage::WebBrowserWindow), 27},
    {sipName_WebKit, static_cast<int>(::QWebPage::WebKit), 12},
    {sipName_WebModalDialog, static_cast<int>(::QWebPage::WebModalDialog), 27},
};

PyDoc_STRVAR(doc_QWebPage, "\1QWebPage(parent: Optional[QObject] = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QWebPage[] = {
    {"featurePermissionRequestCanceled(QWebFrame*,QWebPage::Feature)", "\1featurePermissionRequestCanceled(self, frame: Optional[QWebFrame], feature: QWebPage.Feature)", SIP_NULLPTR, SIP_NULLPTR},
    {"featurePermissionRequested(QWebFrame*,QWebPage::Feature)", "\1featurePermissionRequested(self, frame: Optional[QWebFrame], feature: QWebPage.Feature)", SIP_NULLPTR, SIP_NULLPTR},
    {"viewportChangeRequested()", "\1viewportChangeRequested(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"applicationCacheQuotaExceeded(QWebSecurityOrigin*,quint64,quint64)", "\1applicationCacheQuotaExceeded(self, origin: Optional[QWebSecurityOrigin], defaultOriginQuota: int, totalSpaceNeeded: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"restoreFrameStateRequested(QWebFrame*)", "\1restoreFrameStateRequested(self, frame: Optional[QWebFrame])", SIP_NULLPTR, SIP_NULLPTR},
    {"saveFrameStateRequested(QWebFrame*,QWebHistoryItem*)", "\1saveFrameStateRequested(self, frame: Optional[QWebFrame], item: Optional[QWebHistoryItem])", SIP_NULLPTR, SIP_NULLPTR},
    {"databaseQuotaExceeded(QWebFrame*,QString)", "\1databaseQuotaExceeded(self, frame: Optional[QWebFrame], databaseName: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"contentsChanged()", "\1contentsChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"microFocusChanged()", "\1microFocusChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"downloadRequested(QNetworkRequest)", "\1downloadRequested(self, request: QNetworkRequest)", SIP_NULLPTR, SIP_NULLPTR},
    {"unsupportedContent(QNetworkReply*)", "\1unsupportedContent(self, reply: Optional[QNetworkReply])", SIP_NULLPTR, SIP_NULLPTR},
    {"menuBarVisibilityChangeRequested(bool)", "\1menuBarVisibilityChangeRequested(self, visible: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"statusBarVisibilityChangeRequested(bool)", "\1statusBarVisibilityChangeRequested(self, visible: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"toolBarVisibilityChangeRequested(bool)", "\1toolBarVisibilityChangeRequested(self, visible: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"linkClicked(QUrl)", "\1linkClicked(self, url: QUrl)", SIP_NULLPTR, SIP_NULLPTR},
    {"printRequested(QWebFrame*)", "\1printRequested(self, frame: Optional[QWebFrame])", SIP_NULLPTR, SIP_NULLPTR},
    {"windowCloseRequested()", "\1windowCloseRequested(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"scrollRequested(int,int,QRect)", "\1scrollRequested(self, dx: int, dy: int, scrollViewRect: QRect)", SIP_NULLPTR, SIP_NULLPTR},
    {"repaintRequested(QRect)", "\1repaintRequested(self, dirtyRect: QRect)", SIP_NULLPTR, SIP_NULLPTR},
    {"geometryChangeRequested(QRect)", "\1geometryChangeRequested(self, geom: QRect)", SIP_NULLPTR, SIP_NULLPTR},
    {"frameCreated(QWebFrame*)", "\1frameCreated(self, frame: Optional[QWebFrame])", SIP_NULLPTR, SIP_NULLPTR},
    {"selectionChanged()", "\1selectionChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"statusBarMessage(QString)", "\1statusBarMessage(self, text: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"linkHovered(QString,QString,QString)", "\1linkHovered(self, link: Optional[str], title: Optional[str], textContent: Optional[str])", SIP_NULLPTR, SIP_NULLPTR},
    {"loadStarted()", "\1loadStarted(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"loadProgress(int)", "\1loadProgress(self, progress: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"loadFinished(bool)", "\1loadFinished(self, ok: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QWebPage = {
    &::QWebPage::staticMetaObject,
    0,
    signals_QWebPage,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtWebKitWidgets_QWebPage = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QWebPage,
        SIP_NULLPTR,
        &plugin_QWebPage,
    },
    {
        sipNameNr_QWebPage,
        {0, 0, 1},
        58, methods_QWebPage,
        110, enummembers_QWebPage,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QWebPage,
    -1,
    -1,
    supers_QWebPage,
    SIP_NULLPTR,
    init_type_QWebPage,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QWebPage,
    SIP_NULLPTR,
    array_QWebPage,
    SIP_NULLPTR,
    release_QWebPage,
    cast_QWebPage,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QWebPage,
    sizeof (::QWebPage),
};
